@@ -24,7 +24,7 @@
 #include "ephy-extensions-manager-ui-extension.h"
 #include "extensions-manager-ui.h"
 
-#include <epiphany/ephy-extension.h>
+#include <epiphany/epiphany.h>
 
 #include "ephy-gui.h"
 #include "ephy-debug.h"
@@ -176,10 +176,9 @@ static void
 help_cb (GtkAction *action,
 	 EphyWindow *window)
 {
-	ephy_gui_help_with_doc_id (GTK_WINDOW (window),
-				   "epiphany-extensions",
-				   "epiphany-extensions",
-				   "");
+	ephy_gui_help (GTK_WINDOW (window),
+		       "epiphany-extensions",
+		       "");
 }
 
 static void
