@@ -22,7 +22,7 @@
 #define EPHY_SIDEBAR_H
 
 #include <glib-object.h>
-#include <gtk/gtkvbox.h>
+#include <gtk/gtk.h>
 	
 G_BEGIN_DECLS
 
